Module deprecated

Module deprecated 

Deprecated testing utilities.

The utilities in this module are considered deprecated and new tests should no longer use them. However they are not yet marked as #[deprecated] to avoid a massive amount of warnings during compilation.

Modules

commands
locale_override
macros

Structs

Outcome

Functions

nu_repl_code
shell_os_paths