pub fn assert_contains_not<H, N>(needle: N, haystack: H)Expand description
Assert that a haystack does not contain the given needle.
Uses the Container abstraction so it works with slices, vectors, sets,
maps (by key), strings, and ranges.
The error message includes both the container and the item for quick debugging.
Panics
Panics if haystack.contains(needle) returns true.